pub struct TraceEntryParser;Expand description
A parser for trace entries that formats them into human-readable strings.
Implementations
Sourceimpl TraceEntryParser
impl TraceEntryParser
Sourcepub fn parse<K: KernelTraceOps>(
tracepoint_map: &TracePointMap<K>,
cmdline_cache: &TraceCmdLineCache,
record: &TracePipeRecord,
) -> String
pub fn parse<K: KernelTraceOps>( tracepoint_map: &TracePointMap<K>, cmdline_cache: &TraceCmdLineCache, record: &TracePipeRecord, ) -> String
Parse the trace entry and return a formatted string.